/**
 * Copyright (c) 2010 jolira. All rights reserved. This program and the accompanying materials are made available under
 * the terms of the GNU Public License 2.0 which is available at http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 */

package com.google.code.joliratools.logdb.parser;

/**
 * The callback interface used for processing data identified by the parser.
 * 
 * @author jfk
 * @since 1.0
 */
public interface LogListener {

    public static final int X = -1;

    /**
     * This method deals with strings that have no recognized header. The only time such string can happen is in the
     * begining of the input stream
     * 
     * @param junk
     *            string
     */
    void junk(String junk);

    /**
     * This method is called if the the parser has successfully recognized a log record.
     * 
     * @param timestamp
     *            the timestamp found in the log record
     * @param clazz
     *            the class name found in the log record
     * @param method
     *            the method name found in the log record
     * @param level
     *            the log level found in the log record
     * @param id
     *            the id of the matched record (parser specific value, such as the regex)
     * @param variables
     * @param lineNumberPlaceholder
     */
    void recognized(long timestamp, String clazz, String method, String level, String id, String[] variables,
            int lineNumberPlaceholder);

    /**
     * This method is called if the the parser failed to find a matching regular expression for the log record.
     * 
     * @param timestamp
     *            the timestamp found in the log record
     * @param clazz
     *            the class name found in the log record
     * @param method
     *            the method name found in the log record
     * @param level
     *            the log level found in the log record
     * @param record
     * @param lineNumber
     */
    void unrecognized(long timestamp, String clazz, String method, String level, String record, int lineNumber);
}
